@@ -86,13 +86,15 @@ def deliver_data(job_uuid, bucket_name, file_pattern, platform_name, destination
             chunk_number=chunk_start_number
     ):
         chunk_start = datetime.utcnow()
-
+        tb = None
         try:
             success = distribution_retry_wrapper(
                 destination=destination, platform_name=platform_name, segments=segment_mapping, local_path=local_path,
                 chunk_number=chunk_number, start_time=start_time, id_types=id_types, operations=operations
             )
         except Exception as e:
+            import traceback
+            tb = traceback.format_exc()
             success = False
             if get_settings()['environment'] not in {'qa', 'prod'}:
                 raise e
@@ -105,7 +107,7 @@ def deliver_data(job_uuid, bucket_name, file_pattern, platform_name, destination
                     segment_uuid=segment_uuid
                 )
         log_chunk_delivery(success=success, start=chunk_start, chunk_number=chunk_number, destination=destination,
-                           segments=segment_mapping, job_uuid=job_uuid, platform_name=platform_name)
+                           segments=segment_mapping, job_uuid=job_uuid, platform_name=platform_name, traceback=tb)
 
     end_time = datetime.utcnow()
 
@@ -117,9 +119,17 @@ def deliver_data(job_uuid, bucket_name, file_pattern, platform_name, destination
     return dict(job_uuid=job_uuid, file_pattern=file_pattern, chunk_start_number=chunk_start_number)
 
 
-def log_chunk_delivery(success, start, destination, chunk_number, segments, job_uuid, platform_name, error_type=None):
+def log_chunk_delivery(success, start, destination, chunk_number, segments, job_uuid, platform_name, error_type=None, traceback=None):
     from stratus_api.core import log_event
     from datetime import datetime
+    payload = dict(
+            job_uuid=job_uuid,
+            platform_name=platform_name,
+            success=success,
+            chunk_number=chunk_number
+        )
+    if traceback:
+        payload['traceback'] = traceback
     log_event(
         level='info',
         start=start,
@@ -127,12 +137,7 @@ def log_chunk_delivery(success, start, destination, chunk_number, segments, job_
         status='success' if success else 'failure',
         process_type='segment_delivery',
         failure_classification=error_type,
-        payload=dict(
-            job_uuid=job_uuid,
-            platform_name=platform_name,
-            success=success,
-            chunk_number=chunk_number
-        ),
+        payload=payload,
         attributes=dict(
             destination_uuid=destination['destination_uuid'],
             platform_uuid=destination['platform_uuid'],
@@ -148,7 +153,7 @@ def distribution_failed(value):
     return value is False
 
 
-@retry(stop=stop_after_attempt(3), reraise=False, wait=wait_random_exponential(multiplier=.5, max=5),
+@retry(stop=stop_after_attempt(3), reraise=True, wait=wait_random_exponential(multiplier=.5, max=5),
        retry=retry_any(retry_if_result(distribution_failed), retry_if_exception_type(Exception)))
 def distribution_retry_wrapper(**kwargs):
     from stratus_api.integrations import get_integration_function
